<?php

namespace IPS\bookmark\extensions\core\GroupForm;

/* To prevent PHP errors (extending class does not exist) revealing path */
if (!\defined('\IPS\SUITE_UNIQUE_KEY')) {
    header((isset($_SERVER['SERVER_PROTOCOL']) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0') . ' 403 Forbidden');
    exit;
}

/**
 * Admin CP Group Form
 */
class _Bookmark
{
    /**
     * Process Form
     *
     * @param \IPS\Helpers\Form $form The form
     * @param \IPS\Member\Group $group Existing Group
     * @return    void
     */
    public function process(&$form, $group)
    {
		if ( $group->g_id != \IPS\Settings::i()->guest_group )
		{
			if( $group->g_id )
			{
				$bookmarkPerms = $group::bookmarkPerms( $group->g_id );
			}
			else
			{
				$bookmarkPerms = [
					'can_create_bookmarks' => 0,
					'can_create_private_bookmarks' => 0
				];
			}

			$form->add(new \IPS\Helpers\Form\YesNo('can_create_bookmarks', $bookmarkPerms['can_create_bookmarks'], FALSE, ['togglesOn' => ['can_create_private_bookmarks']]));
			$form->add(new \IPS\Helpers\Form\YesNo('can_create_private_bookmarks', $bookmarkPerms['can_create_private_bookmarks'], FALSE, [], NULL, NULL, NULL, 'can_create_private_bookmarks'));

		}
	}

    /**
     * Save
     *
     * @param array $values Values from form
     * @param \IPS\Member\Group $group The group
     * @return    void
     */
    public function save($values, &$group)
    {
		if ( $group->g_id != \IPS\Settings::i()->guest_group )
		{
			$update = array();

			$update['group_id'] = $group->g_id;
			$update['can_create_bookmarks'] = $values['can_create_bookmarks'];

			if (!isset($values['can_create_private_bookmarks']) or $values['can_create_bookmarks'] === FALSE) {
				$values['can_create_private_bookmarks'] = FALSE;
			}

			$update['can_create_private_bookmarks'] = $values['can_create_private_bookmarks'];

			\IPS\Db::i()->insert('bookmark_grouppermissions', $update, TRUE);

			unset($values['can_create_bookmarks']);
			unset($values['can_create_private_bookmarks']);
		}
        return $values;
    }
}