<?php

namespace IPS\bookmark\extensions\core\Notifications;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * Notification Options
 */
class _Bookmark
{

	public static function configurationOptions( \IPS\Member $member = NULL )
	{
		return array(
			'bookmarked'	=> array(
				'type'				=> 'standard',
				'notificationTypes'	=> array( 'bookmarked' ),
				'title'				=> 'notifications__bookmark_Bookmark',
				'showTitle'			=> FALSE,
				'description'		=> 'notifications__bookmark_Bookmark',
				'default'			=> array( 'inline' ),
				'disabled'			=> array('email', 'push')
			)
		);
	}

	// For each type of notification you need a method like this which controls what will be displayed when the user clicks on the notification icon in the header:
	// Note that for each type of notification you must *also* create email templates. See documentation for details: https://remoteservices.invisionpower.com/docs/devdocs-notifications

	/**
	 * Parse notification: key
	 *
	 * @param	\IPS\Notification\Inline	$notification	The notification
	 * @return	array
	 * @code
	 return [
		 'title'		=> "Mark has replied to A Topic",	// The notification title
		 'url'			=> \IPS\Http\Url::internal( ... ),	// The URL the notification should link to
		 'content'		=> "Lorem ipsum dolar sit",			// [Optional] Any appropriate content. Do not format this like an email where the text
		 													// 	 explains what the notification is about - just include any appropriate content.
		 													// 	 For example, if the notification is about a post, set this as the body of the post.
		 'author'		=>  \IPS\Member::load( 1 ),			// [Optional] The user whose photo should be displayed for this notification
	 ];
	 * @endcode
	 */
	public function parse_bookmarked( \IPS\Notification\Inline $notification )
	{
		$item = $notification->item;

		if ( !$item)
		{
			/* the item was deleted, but there was an issue and the bookmark notificaiton wasn't deleted, so delete it now */
			$notification->delete();
			return NULL;
		}

		if ( isset( $notification->extra['member_id'] ) )
		{
			$member = \IPS\Member::load( $notification->extra['member_id'] );
		}
		else
		{
			throw new \OutOfRangeException;
		}


		$title = $item::$title;
		$container = ( $item instanceof \IPS\Content\Item ) ? $item : $item->item();

		$containerTitle = $container->mapped('title');


		if ( $item instanceof  \IPS\Content\Item )
		{
			$string = "content_bookmarked";
			return [
				'title'		=> \IPS\Member::loggedIn()->language()->addToStack($string, FALSE, ['sprintf' => [
					$member->name,
					$member->language()->addToStack( $title ),
					$containerTitle
				] ]),
				'url'			=> $item->url(),	// The URL the notification should link to
				'author'		=>  $member,			// [Optional] The user whose photo should be displayed for this notification
			];
		}
		else
		{
			$string = 'content_comment_bookmarked';
			return [
				'title'		=> \IPS\Member::loggedIn()->language()->addToStack($string, FALSE, ['sprintf' => [
					$member->name,
					$member->language()->addToStack( $title ),
					$containerTitle
				] ]),
				'url'			=> $item->url(),	// The URL the notification should link to
				'author'		=>  $member,			// [Optional] The user whose photo should be displayed for this notification
			];
		}
	}
}