<?php
/**
 * @brief		Profile extension: Bookmarks
 * @author		<a href='http://www.invisionpower.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) 2001 - 2016 Invision Power Services, Inc.
 * @license		http://www.invisionpower.com/legal/standards/
 * @package		IPS Community Suite
 * @subpackage	bookmark content
 * @since		23 Apr 2017
 * @version		SVN_VERSION_NUMBER
 */

namespace IPS\bookmark\extensions\core\Profile;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * @brief	Profile extension: Bookmarks
 */
class _Bookmarks
{
	/**
	 * Member
	 */
	protected $member;
	
	/**
	 * Constructor
	 *
	 * @param	\IPS\Member	$member	Member whose profile we are viewing
	 * @return	void
	 */
	public function __construct( \IPS\Member $member )
	{
		$this->member = $member;
	}
	
	/**
	 * Is there content to display?
	 *
	 * @return	bool
	 */
	public function showTab()
	{
		$where[]  = array( 'member_id=?', $this->member->member_id );
		$where[] = array( 'visibility_type=1 OR ( visibility_type=2 and member_id=?)',\IPS\Member::loggedIn()->member_id  ) ;

		$select = \IPS\Db::i()->select( 'COUNT(*)', 'bookmark_items', $where );
		return (bool) $select->first();
	}
	
	/**
	 * Display
	 *
	 * @return	string
	 */
	public function render()
	{
		$table = new \IPS\bookmark\Bookmark\Table( $this->member->url()->setQueryString( 'tab', 'node_bookmark_Bookmarks') );
		$table->isProfile = TRUE;
		$table->setMember( $this->member );
		$table->sortDirection = $table->sortDirection ?: 'asc';

		return (string) $table;
	}
}