<?php
/**
 * @brief		Activity stream items extension: Bookmarked
 * @author		<a href='http://www.invisionpower.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) 2001 - 2017 Invision Power Services, Inc.
 * @license		http://www.invisionpower.com/legal/standards/
 * @package		IPS Community Suite
 * @subpackage	bookmark content
 * @since		24 Apr 2017
 * @version		SVN_VERSION_NUMBER
 */

namespace IPS\bookmark\extensions\core\StreamItems;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * @brief	Activity stream items extension: Bookmarked
 */
class _Bookmarked
{
	/**
	 * Is there content to display?
	 *
	 * @param	\IPS\Member|NULL	$author		The author to limit extra items to
	 * @param	Timestamp|NULL	$lastTime	If provided, only items since this date are included. If NULL, it works out which to include based on what results are being shown
	 * @param	Timestamp|NULL	$firstTime	If provided, only items before this date are included. If NULL, it works out which to include based on what results are being shown
	 * @return	array Array of \IPS\Content\Search\Result\Custom objects
	 */
	public function extraItems( $author=NULL, $lastTime=NULL, $firstTime=NULL )
	{
		$bookmarks = array();

		$where = array( array( 'date>? and visibility_type=?', $lastTime, 1 ) );
		if ( $firstTime )
		{
			$where[] = array( 'date<?', $firstTime );
		}
		if ( $author )
		{
			$where[] = array( 'member_id=?', $author->member_id );
		}
		foreach ( \IPS\Db::i()->select( '*', 'bookmark_items', $where, 'date DESC', 10 ) as $bookmark )
        {
            $member = \IPS\Member::load( $bookmark['member_id'] );
            $item = \IPS\bookmark\Bookmark::load( $bookmark['id'] );
            if ( $item AND $item->item )
            {
                $bookmarks[] = new \IPS\Content\Search\Result\Custom( \IPS\DateTime::ts( $bookmark[ 'date' ] ), \IPS\Member::loggedIn()->language()->addToStack( 'bookmarks_activity_stream_bookmarked', FALSE, array( 'htmlsprintf' => array( \IPS\Theme::i()->getTemplate( 'global', 'core', 'front' )->userLink( $member ), $item->item->indefiniteArticle(), $item->item->url(), $item->title ) ) ) );
            }
            else
            {
                #
            }
		}

		/* Return */
		if ( !empty( $bookmarks ) )
		{
			return $bookmarks;
		}

		return array();
	}

}