//<?php

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	exit;
}

class bookmark_hook_Controller extends _HOOK_CLASS_
{

	/**
	 * @param $class
	 * @return \IPS\Helpers\Form
	 */
    protected function getBookmarkForm( $class )
    {
	try
	{
		try
		{
				$member = \IPS\Member::loggedIn();
		
				$options =
					[
						1 => 'bookmark_public',
						2 => 'bookmark_private'
					];
		
				$form = new \IPS\Helpers\Form('form','save', NULL, array( 'data-controller' => 'bookmark.front.bookmark.form' ) );
				/* can this member have hidden bookmarks */
				if ( \IPS\Application::load('bookmark')->canUseBookmarks( TRUE ) )
				{
					$form->add(new \IPS\Helpers\Form\Select( 'bookmark_type', null, true, array('options' => $options ) ) );
				}
				else
				{
					$form->hiddenValues['bookmark_type'] = 1;
				}
				if( !\IPS\Settings::i()->bookmark_autosticky )
				{
					$form->add( new \IPS\Helpers\Form\YesNo( 'bookmark_sticky', \IPS\Settings::i()->bookmark_autosticky, FALSE ) );
				}
		
		/*
		$form->add( new \IPS\Helpers\Form\Custom( 'bookmark_color', 'none', FALSE, array( 'getHtml' => function( $element )
		{
			return \IPS\Theme::i()->getTemplate( 'forms', 'core', 'front' )->colorSelection( $element->name, $element->value );
		} ), NULL, NULL, NULL, 'message_color' ) );
*/
		
		        $form->add( new \IPS\Helpers\Form\Node( 'bookmark_category', NULL, FALSE, array(
						'class'		      => '\IPS\bookmark\Bookmark\Category',
						'disabled'	      => false,
						'permissionCheck' => function( $node ) use ( $member )
						{
							return $node->member_id == $member->member_id;
						},
					    'forceOwner'			=> \IPS\Member::loggedIn()
					), NULL, NULL, '<br><a href="#" data-action="addCategory" class="ipsButton ipsButton_action ipsButton_positive">' . \IPS\Member::loggedIn()->language()->addToStack('bookmark_add_new_category') . '</a>'));
		
		        $form->add( new \IPS\Helpers\Form\Text('category_name_new', NULL, FALSE, array(),NULL,NULL,NULL,'category_name_new') );
				$form->add( new \IPS\Helpers\Form\Text('bookmark_title', NULL, FALSE ) );
		
				$form->add(new \IPS\Helpers\Form\TextArea( 'bookmark_note' ) );
				$form->hiddenValues['content_type'] = $class;
				$form->hiddenValues['content_id'] = \IPS\Request::i()->id;
				$form->hiddenValues['isButton'] = \IPS\Request::i()->isButton;
		
				return $form;
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}
	
			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }

    protected function removeBookmark()
    {
	try
	{
		try
		{
				/* Init */
				$class = static::$contentModel;
				$item = $class::loadAndCheckPerms( \IPS\Request::i()->id );
		
				if ( !$item->canBookmark() )
				{
					\IPS\Output::i()->error( 'no_module_permission', '2/bookmark4', 403, '' );
				}
		
				\IPS\Session::i()->csrfCheck();
		
				$item->removeBookmark();
		
				if ( \IPS\Request::i()->isAjax() )
				{
					$this->getBookmarkAjaxResponse($item);
					return;
				}
				else
				{
					\IPS\Output::i()->redirect( $item->url(), 'deleted' );
				}
		
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}
	
			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }

    protected function saveBookmarkSimple($item)
	{
		try
		{
			try
			{
				$data = array(
					'bookmark_type' =>  2,
					'bookmark_title' =>  '',
					'bookmark_note' => '',
					'bookmark_color' => NULL,
				);
				return $this->saveBookmark($item, $data);
		
			}
			catch ( \Error | \RuntimeException $e )
			{
				if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
				{
					\IPS\Log::log( $e, 'hook_exception' );
				}
	
				if ( method_exists( get_parent_class(), __FUNCTION__ ) )
				{
					return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
				}
				else
				{
					throw $e;
				}
			}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}

			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}

    protected function saveBookmark($item, array $values)
    {
	try
	{
		try
		{
				if ( isset( $values['bookmark_category'] ) and \is_object($values['bookmark_category']))
				{
					$category = $values['bookmark_category']->_id;
				}
				else if ( isset( $values['category_name_new'] ) AND $values['category_name_new'] )
				{
				    $categoryNew = new \IPS\bookmark\Bookmark\Category();
					$categoryNew->title = $values['category_name_new'];
					$categoryNew->member_id = \IPS\Member::loggedIn()->member_id;
					$categoryNew->save();
				    $category = $categoryNew->id;
				}
				else
		        {
					$category = 0;
				}
		
				if ( !isset( $values['bookmark_color'] ) )
		        {
					$values['bookmark_color'] = NULL;
		        }
		
				if( \IPS\Settings::i()->bookmark_autosticky == 1 )
				{
					$values['bookmark_sticky'] = \IPS\Settings::i()->bookmark_autosticky;
				}
		
				$bookmark = $item->bookmark( $values['bookmark_type'], $values['bookmark_note'], $values['bookmark_color'], $category, $values['bookmark_title'], $values['bookmark_sticky'] );
		
				/* send notification */
				if ( $bookmark AND $values['bookmark_type'] == 1)
				{
					$bookmark->sendNotification();
				}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}
	
			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }



    protected function bookmark()
    {
	try
	{
		try
		{
				/* Init */
				$class = static::$contentModel;
				$item = $class::loadAndCheckPerms( \IPS\Request::i()->id );
		
				if ( !$item->canBookmark() )
				{
					\IPS\Output::i()->error( 'no_module_permission', '2/bookmark3', 403, '' );
				}
		
				\IPS\Session::i()->csrfCheck();
		
				if ( \IPS\Application::load( 'bookmark')->isSimpleMode() )
				{
					$this->saveBookmarkSimple($item);
					if ( \IPS\Request::i()->isAjax() )
					{
						$this->getBookmarkAjaxResponse($item, FALSE);
						return;
					}
					else
					{
						\IPS\Output::i()->redirect( $item->url() );
					}
				}
				else
				{
					$form = $this->getBookmarkForm( $class );
		
					if ( $values = $form->values() )
					{
						$this->saveBookmark($item, $values);
		
						if ( \IPS\Request::i()->isAjax() )
						{
							$this->getBookmarkAjaxResponse($item, FALSE);
							return;
						}
						else
						{
							\IPS\Output::i()->redirect( $item->url() );
						}
					}
		
					\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate( 'global', 'core', 'front')->genericBlock( $form, '', 'ipsPad' );
				}
		
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}
	
			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }

    public function getBookmarkAjaxResponse($item, $add=TRUE)
    {
	try
	{
		try
		{
		        $data = [];
		        if ( $add )
		        {
					$data['newurl'] = $item->url('bookmark')->csrf();
		        }
		        else
		        {
					$data['newurl'] = $item->url('removeBookmark')->csrf();
		        }
		
		        \IPS\Output::i()->json( $data );
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}
	
			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }



    protected function _removeBookmark($commentClass, $comment, $item)
    {
	try
	{
		try
		{
				if ( !$comment->canBookmark() )
				{
					\IPS\Output::i()->error( 'no_module_permission', '1/bookmark1', 403 );
				}
		
				\IPS\Session::i()->csrfCheck();
				
		        $comment->removeBookmark();
				if ( \IPS\Request::i()->isAjax() )
				{
					$this->getBookmarkAjaxResponse($comment, TRUE );
					return;
				}
				else
				{
					\IPS\Output::i()->redirect( $comment->url(), 'deleted' );
				}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}
	
			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }


    protected function _bookmark( $commentClass, $comment, $item )
	{
		try
		{
			try
			{
				if (!$comment->canBookmark())
				{
					\IPS\Output::i()->error('no_module_permission', '1/bookmark2', 403);
				}
				\IPS\Session::i()->csrfCheck();
		
				if ( \IPS\Application::load('bookmark')->isSimpleMode() )
				{
					$this->saveBookmarkSimple($comment);
					if ( \IPS\Request::i()->isAjax() )
					{
						$this->getBookmarkAjaxResponse($comment, FALSE);
						return;
					}
					else
					{
						\IPS\Output::i()->redirect( $comment->url() );
					}
				}
				else
				{
					$form = $this->getBookmarkForm( $commentClass );
		
					if ( $values = $form->values() )
					{
						$this->saveBookmark($comment, $values);
						if ( \IPS\Request::i()->isAjax() )
						{
							$this->getBookmarkAjaxResponse($comment, true);
							return;
						}
						else
						{
							\IPS\Output::i()->redirect( $comment->url() );
						}
					}
					\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate( 'global', 'core', 'front')->genericBlock( $form, '', 'ipsPad' );
				}
		}
		catch ( \Error | \RuntimeException $e )
		{
			if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
			{
				\IPS\Log::log( $e, 'hook_exception' );
			}
	
			if ( method_exists( get_parent_class(), __FUNCTION__ ) )
			{
				return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
			}
			else
			{
				throw $e;
			}
		}
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }


}
