<?php
/**
 * @brief		category
 * @author		<a href='http://www.invisionpower.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) 2001 - 2016 Invision Power Services, Inc.
 * @license		http://www.invisionpower.com/legal/standards/
 * @package		IPS Community Suite
 * @subpackage	Favorite Content Bookmarks
 * @since		02 Jun 2017
 * @version		SVN_VERSION_NUMBER
 */

namespace IPS\bookmark\modules\front\bookmarks;

/* To prevent PHP errors (extending class does not exist) revealing path */
use IPS\Helpers\Form;
use IPS\Http\Url\Internal;
use IPS\Member;
use IPS\Output;
use IPS\Request;

if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * category
 */
class _category extends basecontroller
{
	protected function manage()
	{
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('bookmark_manage_categories');
		\IPS\Output::i()->breadcrumb[] = array( $this->url, \IPS\Member::loggedIn()->language()->addToStack('bookmark_manage_categories'));
		\IPS\Output::i()->output= \IPS\Theme::i()->getTemplate( 'bookmark', 'bookmark', 'global' )->categoryManage();
	}


	protected function add()
	{
		$form = new Form();
		$cat = new \IPS\bookmark\Bookmark\Category;
		$cat->form($form);
		if ( $values = $form->values() )
		{
			$cat->saveForm( $cat->formatFormValues( $values ) );
			Output::i()->redirect( Internal::internal('app=bookmark&module=bookmarks&controller=category') );
		}
		\IPS\Output::i()->title = Member::loggedIn()->language()->addToStack( 'bookmark_add_new_category' );
		\IPS\Output::i()->breadcrumb[] = array( NULL, Member::loggedIn()->language()->addToStack( 'bookmark_add_new_category' ) );
		\IPS\Output::i()->output = $form->customTemplate( array( \IPS\Theme::i()->getTemplate( 'forms', 'core' ), 'popupTemplate' ) );
	}

	protected function edit()
	{
		try
		{
			$cat = \IPS\bookmark\Bookmark\Category::load( \IPS\Request::i()->category_id );
			if ( !$cat->member_id or $cat->member_id != \IPS\Member::loggedIn()->member_id )
			{
				throw new \OutOfRangeException;
			}
		}
		catch ( \OutOfRangeException $e )
		{
			\IPS\Output::i()->error( 'node_error', '2bookmarkc_cat_edit1', 404, '' );
		}

		$form = new Form();
		$cat->form($form);
		if ( $values = $form->values() )
		{
			$cat->saveForm( $cat->formatFormValues( $values ) );
			Output::i()->redirect( Internal::internal('app=bookmark&module=bookmarks&controller=category') );
		}
		\IPS\Output::i()->output = $form->customTemplate( array( \IPS\Theme::i()->getTemplate( 'forms', 'core' ), 'popupTemplate' ) );
	}

	protected function delete()
	{
		\IPS\Session::i()->csrfCheck();
		\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('delete');

		try
		{
			$cat = \IPS\bookmark\Bookmark\Category::load( \IPS\Request::i()->category_id );
			if ( !$cat->member_id or $cat->member_id != \IPS\Member::loggedIn()->member_id )
			{
				throw new \OutOfRangeException;
			}
		}
		catch ( \OutOfRangeException $e )
		{
			\IPS\Output::i()->error( 'node_error', '2bookmarkc_cat_delete1', 404, '' );
		}

		if ( $cat->hasChildren(NULL, NULL, TRUE ) or $cat->showDeleteOrMoveForm())
		{
			$form = $cat->deleteOrMoveForm( TRUE );
			if ( $values = $form->values() )
			{
				$cat->deleteOrMoveFormSubmit( $values );
				\IPS\Output::i()->redirect( $this->url->setQueryString( array( 'root' => ( $cat->parent() ? $cat->parent()->_id : '' ) ) ), 'deleted' );
			}
			else
			{
				/* Show form */
				\IPS\Output::i()->output = $form->customTemplate( array( \IPS\Theme::i()->getTemplate( 'forms', 'core' ), 'popupTemplate' ) );
				return;
			}
		}
		else
		{
			/* Make sure the user confirmed the deletion */
			\IPS\Request::i()->confirmedDelete('delete_confirm', 'bookmark_delete_confirm_desc');
		}

		$cat->delete();
		if ( Request::i()->returnToOverview)
		{
			Output::i()->redirect( Internal::internal('app=bookmark&module=bookmarks&controller=view') );
		}
		Output::i()->redirect( Internal::internal('app=bookmark&module=bookmarks&controller=category') );
	}
}