<?php
/**
 * @brief		view
 * @author		<a href='http://www.invisionpower.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) 2001 - 2016 Invision Power Services, Inc.
 * @license		http://www.invisionpower.com/legal/standards/
 * @package		IPS Community Suite
 * @subpackage	bookmark content
 * @since		22 Apr 2017
 * @version		SVN_VERSION_NUMBER
 */

namespace IPS\bookmark\modules\front\bookmarks;

/* To prevent PHP errors (extending class does not exist) revealing path */
use IPS\bookmark\Bookmark\Category;
use IPS\Helpers\Form;
use IPS\Member;
use IPS\Output;
use IPS\Request;

if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * view
 */
class _view extends basecontroller
{
	protected function manage()
	{
		\IPS\Output::i()->title = Member::loggedIn()->language()->addToStack( 'my_bookmarks' );

		$table = new \IPS\bookmark\Bookmark\Table( \IPS\Http\Url::internal( 'app=bookmark&module=bookmarks&controller=view', 'front', 'bookmark_cat' ) );
		$table->setMember( \IPS\Member::loggedIn() );
		$table->setCategory( Request::i()->category_id );
		$table->sortDirection = $table->sortDirection ?: 'asc';


		$categories = array( Request::i()->category_id );

		\IPS\Output::i()->sidebar['contextual'] = \IPS\Theme::i()->getTemplate('bookmark', 'bookmark', 'global')->sidebar($categories);

		// TODO what if forums app isn't installed
		\IPS\Output::i()->cssFiles = array_merge( \IPS\Output::i()->cssFiles, \IPS\Theme::i()->css( 'forums.css', 'forums' ) );
		\IPS\Output::i()->output = $table;
	}


	protected function downloadBookmarks()
	{
		if ( Request::i()->type == 'xml' )
		{
            /** @var  $document \IPS\Xml\Rss */
            /** @var  $bookmark \IPS\bookmark\Bookmark\Category */
			$document = \IPS\Xml\Rss::newDocument( $this->url, \IPS\Member::loggedIn()->language()->addToStack('bookmarks'), \IPS\Member::loggedIn()->language()->addToStack('bookmarks') );

			foreach ( \IPS\bookmark\Bookmark\Category::loadByOwner() as $bookmark )
			{
				$document->addItem( $bookmark->title, $bookmark->url(), $bookmark->url());
			}

			/* @note application/rss+xml is not a registered IANA mime-type so we need to stick with text/xml for RSS */
			\IPS\Output::i()->sendOutput( $document->asXML(), 200, 'text/xml',array( 'Content-Disposition' => \IPS\Output::getContentDisposition( 'attachment', 'bookmarks.xml' ) ), FALSE, FALSE, TRUE );
		}
		else
		{
			\IPS\Output::i()->title = \IPS\Member::loggedIn()->language()->addToStack('bookmarks');
			#\IPS\Output::i()->output = \IPS\Theme::i()->getTemplate('bookmark', 'bookmark', 'global')->exportTable();
			\IPS\Output::i()->sendOutput( \IPS\Theme::i()->getTemplate('bookmark', 'bookmark', 'global')->exportTable(), 200, 'text/html',array( 'Content-Disposition' => \IPS\Output::getContentDisposition( 'attachment', 'bookmarks.html' ) ), FALSE, FALSE, TRUE );
		}
	}


	protected function categoryForm()
	{
		$bookmarkCategory = new Category();
		$form = $bookmarkCategory->form();

		if ( $values = $form->values() )
		{
			$bookmarkCategory->saveForm ($values );
			//TODO redirect
		}
		\IPS\Output::i()->output = $form;
	}
	
	// Create new methods with the same name as the 'do' parameter which should execute it
}