<?php

namespace IPS\bookmark;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}


class _Bookmark extends \IPS\Patterns\ActiveRecord
{
	/**
	 * @brief	Database Table
	 */
	public static $databaseTable = 'bookmark_items';

	/**
	 * @brief	Database Prefix
	 */
	public static $databasePrefix = '';

	/**
	 * @brief	Multiton Store
	 */
	protected static $multitons;

	/**
	 * @return mixed
	 */
	public function get_item()
	{
		$class = $this->class;
		$idColumn = static::$databaseColumnId;
		// TODO this needs some further cleanup
		try
		{
			$item = $class::load( $this->content_id );
            return $item;
		}
		catch ( \OutOfRangeException $e )
		{
			\IPS\Log::log( 'invalid_bookmark_item '. $this->$idColumn );
			$this->delete();
		}
		return NULL;

	}

	public static function loadByMember( $class, $id, $memberId)
	{
		$data = \IPS\Db::i()->select( '*', static::$databaseTable, [ 'class=? and content_id=? and member_id=?', $class, $id, $memberId] )->first();
		return static::constructFromData( $data );
	}

	protected function onDelete()
	{
		return FALSE;
		/* Remove Notification */
		$memberIds	= array();
		$idColumn = static::$databaseColumnId;

		\IPS\Db::i()->delete( 'core_notifications', array( 'notification_app=? AND item_id=?', "bookmark", (int) $this->$idColumn ) );
	}


	public static function deleteBookmarkForContent($class, $id)
	{
		\IPS\Db::i()->delete( static::$databaseTable, ['class=? and content_id=?', $class, $id ] );
	}

	public function hasCustomTitle()
	{
		return isset( $this->_data['title'] );
	}

	public function get_title()
	{
		if ( isset( $this->_data['title'] ) AND $this->_data['title'] != '' )
		{
			return $this->_data['title'];
		}
		$container = ( $this->item instanceof \IPS\Content\Item ) ? $this->item : $this->item->item();
		return $container->mapped('title');
	}

	public function get_indefart()
	{
		$container = $this->item;

		return $container::_indefiniteArticle();
	}

	public function get_contentypetitle()
	{
		$container = ( $this->item instanceof \IPS\Content\Item ) ? $this->item : $this->item->item();
		return $container::$title;
	}

	public function sendNotification()
	{
		$member = \IPS\Member::loggedIn();
		$notification = new \IPS\Notification( \IPS\Application::load( 'bookmark' ), 'bookmarked', $this->item, array( $this, $member ), array( "member_id" => $this->member_id) );
		$notification->recipients->attach( $this->item->author() );
		$notification->send();
	}


	public function getContent()
	{
		$class = \get_class($this->item );

		switch ( $class )
		{
			case 'IPS\downloads\File':
				$item = $this->item;
				$url =\IPS\File::get( 'downloads_Screenshots', $this->item->primary_screenshot_thumb )->url;
				return "<img src='{$url}' alt='{$item->caption}' class='ipsImage'>";

			case 'IPS\gallery\Image':
			case 'IPS\gallery\Album\Item':
				$item = $this->item;
				$img =  $item->embedImage();
				return "<img src='{$img->url}' alt='{$item->caption}' class='ipsImage'>";
			default:
				return $this->item->content();
		}
	}

	public static function getMenuBookmarks(\IPS\Member $member = NULL )
	{
		$member = $member ? : \IPS\Member::loggedIn();

		$where = array('member_id=? and sticky=1', $member->member_id );

		$items = \IPS\Db::i()->select('*', static::$databaseTable, $where);
		return new \IPS\Patterns\ActiveRecordIterator( $items, \get_called_class());
	}

	/**
	 * Get output for API
	 *
	 * @param	\IPS\Member|NULL	$authorizedMember	The member making the API request or NULL for API Key / client_credentials
	 * @return	array
	 * @apiresponse	string									title	Bookmark Title
	 * @apiresponse	string									content	Bookmark Content
	 * @apiresponse	\IPS\Member									owner	Bookmark owner/creator
	 */
	public function apiOutput( \IPS\Member $authorizedMember = NULL )
	{
		return [
			'title' => $this->title,
			'content' => $this->getContent(),
            'owner' => \IPS\Member::load( $this->member_id)->apiOutput($authorizedMember)
		];
	}
}