<?php
namespace IPS\bookmark\Bookmark;


trait Bookmarkable
{
	protected $isBookmarkedByCurrentUser = NULL;

	public function canBookmark()
	{

		if( method_exists( get_parent_class(), "canBookmark"))
		{
			$response = parent::canBookmark();
			if( !$response)
			{
				return FALSE;
			}
		}

		if ( !\IPS\Member::loggedIn()->member_id )
		{
			return FALSE;
		}
		\IPS\Output::i()->jsFiles = array_merge( \IPS\Output::i()->jsFiles, \IPS\Output::i()->js( 'front_bookmark.js', 'bookmark', 'front' ) );
		return \IPS\Application::load('bookmark')->canUseBookmarks();
	}

	public static function constructFromData( $data, $updateMultitonStoreIfExists = TRUE )
	{
		$object = parent::constructFromData($data, $updateMultitonStoreIfExists);

		if ( isset( $data['bookmark'] ) )
		{
			if ( isset( $data['bookmark']['id'] ) AND $data['bookmark']['id'] )
			{
				try{
					\IPS\bookmark\Bookmark::constructFromData( $data['bookmark'] );
					$object->isBookmarkedByCurrentUser = TRUE;
				}
				catch ( \Exception $e )
				{
					$object->isBookmarkedByCurrentUser = FALSE;
				}
			}
			else
			{
				$object->isBookmarkedByCurrentUser = FALSE;
			}
		}
		return $object;
	}

	public function isBookmarked()
	{
		if ( isset( $this->isBookmarkedByCurrentUser ) )
		{
			return $this->isBookmarkedByCurrentUser;
		}
		$idColumn = static::$databaseColumnId;
		return ( \IPS\Db::i()->select( 'COUNT(*)', 'bookmark_items', array('member_id=? AND class=? and content_id=?', \IPS\Member::loggedIn()->member_id, \get_called_class(), $this->$idColumn ) )->first() == 1 );
	}

	public function bookmark( $visibilityType = 2, $note='', $color = '', $category = NULL, $title = NULL, $isSticky = FALSE )
	{
		$idColumn = static::$databaseColumnId;
		$class = \get_class( $this );

		$app = explode( '\\', $class );
		if ( \strtolower( $app[1] ) === $app[1] )
		{
			$app = $app[1];
		}
		else
		{
			$app = 'core';
		}
		$bookmark = new    \IPS\bookmark\Bookmark();
		$bookmark->class = $class;
		$bookmark->app = $app;
		$bookmark->content_id = $this->$idColumn;
		$bookmark->color = $color;
		$bookmark->member_id = \IPS\Member::loggedIn()->member_id;
		$bookmark->visibility_type = $visibilityType;
		$bookmark->note = $note;
		$bookmark->date = time();
		$bookmark->category_id = $category;
		$bookmark->title = $title;
		$bookmark->sticky = $isSticky;

		try
		{
			$bookmark->save();
		}
		catch ( \IPS\Db\Exception  $e )
		{
		}

		\IPS\Api\Webhook::fire('fosters.bookmark.added', $bookmark);

		return $bookmark;
	}

	public function removeBookmark()
	{
		$idColumn = static::$databaseColumnId;
		$class = \get_class( $this );
		try
		{
            \IPS\Api\Webhook::fire('fosters.bookmark.removed', $this);
			\IPS\bookmark\Bookmark::loadByMember($class,$this->$idColumn, \IPS\Member::loggedIn()->member_id )->delete();
		}
		catch ( \UnderFlowException $e )
		{

		}
	}

	public function delete()
	{
		$idColumn = static::$databaseColumnId;
		\IPS\bookmark\Bookmark::deleteBookmarkForContent( \get_class( $this ), $this->$idColumn );
		parent::delete();
	}

	public static function joins( \IPS\Content\Item $item )
	{
		$return = parent::joins($item);
		if ( \IPS\Dispatcher::hasInstance() )
		{
			$idColumn = static::$databaseColumnId;
			$return['bookmark'] = array(
				'select'	=> 'bookmark.*',
				'from'		=> array( 'bookmark_items', 'bookmark'),
				'where'		=> array( 'bookmark.member_id=? AND bookmark.class=? AND bookmark.content_id=' . static::$databaseTable . '.' . static::$databasePrefix . $idColumn, \IPS\Member::loggedIn()->member_id, \get_called_class() )
			);
		}

		return $return;
	}
}
