<?php

namespace IPS\bookmark\Bookmark;

/* To prevent PHP errors (extending class does not exist) revealing path */
use IPS\Node\Model;

if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}


class _Category extends Model
{
	/**
	 * @brief	Database Table
	 */
	public static $databaseTable = 'bookmark_categories';

	/**
	 * @brief	Database Prefix
	 */
	public static $databasePrefix = '';

	/**
	 * @brief	Multiton Store
	 */
	protected static $multitons;

	public static $nodeTitle = 'bookmark_category';

	public static $ownerTypes = array( 'member' => 'member_id' );

    /**
     * @param \IPS\Helpers\Form $form
     * @return \IPS\Helpers\Form|void
     */
	public function form( &$form )
	{
		$form->add( new \IPS\Helpers\Form\Text( 'bookmark_category_title', ( $this->id ) ? $this->title : NULL, TRUE ) );
		return $form;
	}

	/**
	 * [Node] Format form values from add/edit form for save
	 *
	 * @param	array	$values	Values from the form
	 * @return	array
	 */
	public function formatFormValues( $values )
	{
		if (isset( $values['bookmark_category_title'] ) )
		{
			$values['title'] = $values['bookmark_category_title'];
			unset( $values['bookmark_category_title'] );
		}

		$values['member_id']	= \IPS\Member::loggedIn()->member_id;
		return $values;
	}

	protected function get__title()
	{
		return $this->title;
	}

	protected $_url = NULL;

	public function url()
	{
			if( $this->_url === NULL )
			{
				$this->_url = \IPS\Http\Url::internal( "app=bookmark&module=bookmarks&controller=view&category_id=" . $this->id, 'front', 'bookmark_cat' );
			}

			return $this->_url;
	}


	public function manageUrl($action, $returnToOverview = FALSE)
	{
		return \IPS\Http\Url::internal( "app=bookmark&module=bookmarks&controller=category&do=" . $action .'&category_id=' . $this->id, 'front', 'bookmark_cat' )
			->csrf()
			->setQueryString('returnToOverview', $returnToOverview);
	}


	function delete()
	{
		\IPS\Db::i()->delete('bookmark_items', ['category_id=?', $this->id ] );

		parent::delete();
	}


	public function get_links()
	{
		return new \IPS\Patterns\ActiveRecordIterator( \IPS\Db::i()->select( '*', 'bookmark_items', ['category_id=?', $this->id ] ), 'IPS\bookmark\Bookmark' );
	}

	public static function getUncategorizedBookmarks( \IPS\Member $member = NULL )
	{
		$member = $member ?: \IPS\Member::loggedIn();
		return new \IPS\Patterns\ActiveRecordIterator( \IPS\Db::i()->select( '*', 'bookmark_items', ['category_id=? and member_id=? ', 0, $member->member_id ] ), 'IPS\bookmark\Bookmark' );
	}

	public function getItemCount()
	{
		return (int) \IPS\Db::i()->select( 'COUNT(*)', 'bookmark_items', array( 'category_id=?', $this->id ) )->first();
	}

	/**
	 * Form to delete or move content
	 *
	 * @param	bool	$showMoveToChildren	If TRUE, will show "move to children" even if there are no children
	 * @return	\IPS\Helpers\Form
	 */
	public function deleteOrMoveForm( $showMoveToChildren=FALSE )
	{
		$member = \IPS\Member::loggedIn();

		$hasContent	= (bool) $this->getItemCount();
		$form = new \IPS\Helpers\Form('delete_node_form','delete', NULL, array( 'data-controller' => 'bookmark.front.bookmark.form' ) );
		$form->addMessage( 'bookmarks_category_delete_confirm' );
		if ( $hasContent )
		{
			$form->add( new \IPS\Helpers\Form\Node( 'bookmarks_choose_new_category', 0, TRUE, array(
				'class'		      => '\IPS\bookmark\Bookmark\Category',
				'disabled'	      => false,
				'permissionCheck' => function( $node ) use ( $member )
				{
					return $node->member_id == $member->member_id;
				},
				'disabled' => array( $this->_id ),
				'forceOwner'			=> \IPS\Member::loggedIn(),
				'zeroVal' => 'bookmarks_delete_links'
			), NULL, NULL, '<br><a href="#" data-action="addCategory">' . \IPS\Member::loggedIn()->language()->addToStack('bookmark_add_new_category') . '</a>'));
			$form->add( new \IPS\Helpers\Form\Text('category_name_new', NULL, FALSE, array(),NULL,NULL,NULL,'category_name_new') );
		}

		return $form;
	}

	/**
	 * Handle submissions of form to delete or move content
	 *
	 * @param	array	$values			Values from form
	 * @return	void
	 */
	public function deleteOrMoveFormSubmit( $values )
	{
		if ( isset($values['category_name_new']) AND $values['category_name_new'] )
		{
			$categoryNew = new \IPS\bookmark\Bookmark\Category();
			$categoryNew->title = $values['category_name_new'];
			$categoryNew->member_id = \IPS\Member::loggedIn()->member_id;
			$categoryNew->save();
			$category = $categoryNew->id;
			\IPS\Db::i()->update( "bookmark_items", 'category_id=' . $category, ['category_id=?', $this->_id] );
		}
		else if ( isset( $values['bookmarks_choose_new_category'] ) AND is_object($values['bookmarks_choose_new_category'] ) )
		{
			\IPS\Db::i()->update( "bookmark_items", 'category_id=' . $values['bookmarks_choose_new_category']->_id, ['category_id=?', $this->_id] );
		}

		$this->delete();
	}

}