<?php
/**
 * @brief		Notifications Table Helper
 * @author		<a href='http://www.invisionpower.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) 2001 - 2016 Invision Power Services, Inc.
 * @license		http://www.invisionpower.com/legal/standards/
 * @package		IPS Community Suite
 * @since		3 July 2014
 * @version		SVN_VERSION_NUMBER
 */

namespace IPS\bookmark\Bookmark;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

class _Table extends \IPS\Helpers\Table\Table
{
	/**
	 * @brief	Sort options
	 */
	public $sortOptions = array( 'date' );

	public $isProfile = FALSE;

	/**
	 * @brief	Rows
	 */
	protected static $rows = null;

	/**
	 * @brief	WHERE clause
	 */
	protected $where = array();

	/**
	 * Constructor
	 *
	 * @param	\IPS\Http\Url	Base URL
	 * @return	void
	 */
	public function __construct( \IPS\Http\Url $url=NULL )
	{
		/* Init */
		parent::__construct( $url );

		$this->filters = array(
			'bookmark_sticky'	=> array( 'sticky=?', '1' ),
		);
		$this->tableTemplate = array( \IPS\Theme::i()->getTemplate( 'bookmark', 'bookmark', 'global' ), 'bookmarkTable' );
		$this->rowsTemplate = array( \IPS\Theme::i()->getTemplate( 'bookmark', 'bookmark', 'global' ), 'bookmarkRows' );

	}

	/**
	 * Set member
	 *
	 * @param	\IPS\Member	$member		The member to filter by
	 * @return	void
	 */
	public function setMember( \IPS\Member $member )
	{
		$this->where[] = array( 'member_id=?', $member->member_id );
	}

	public function setCategory( $categoryId = NULL )
	{
		if ( $categoryId )
		{
			\IPS\Output::i()->title = \IPS\Output::i()->title . ' - ' . Category::load($categoryId)->_title;
			\IPS\Output::i()->breadcrumb[] = array( $this->baseUrl->setQueryString('category_id', $categoryId ), Category::load($categoryId)->_title);
			$this->where[] = ['category_id=?', $categoryId];
			$this->baseUrl = $this->baseUrl->setQueryString('category_id', $categoryId);
		}
	}

	/**
	 * Get rows
	 *
	 * @param	array	$advancedSearchValues	Values from the advanced search form
	 * @return	array
	 */
	public function getRows( $advancedSearchValues=NULL )
	{
		if ( static::$rows === NULL )
		{
			/* Check sortBy */
			$this->sortBy = \in_array( $this->sortBy, $this->sortOptions ) ? $this->sortBy : 'date';

			/* What are we sorting by? */
			$sortBy = $this->sortBy . ' ' . ( mb_strtolower( $this->sortDirection ) == 'asc' ? 'asc' : 'desc' );

			/* Specify filter in where clause */
			$where = isset( $this->where ) ? \is_array( $this->where ) ? $this->where : array( $this->where ) : array();

			/* Limit applications */
			$where[] = array( "app IN('" . implode( "','", array_keys( \IPS\Application::enabledApplications() ) ) . "')" );

			if ( $this->filter and isset( $this->filters[ $this->filter ] ) )
			{
				$where[] = \is_array( $this->filters[ $this->filter ] ) ? $this->filters[ $this->filter ] : array( $this->filters[ $this->filter ] );
			}

			if( \IPS\Member::loggedIn()->member_id )
			{
				$where[] = array( '( visibility_type=1 OR ( visibility_type=2 and member_id=' . \IPS\Member::loggedIn()->member_id . ') )' ) ;
			}
			else
			{
				$where[] = array( ' visibility_type=1' ) ;
			}


			/* Get Count */
			$count = \IPS\Db::i()->select( 'COUNT(*) as cnt', 'bookmark_items', $where )->first();

			$this->pages = ceil( $count / $this->limit );

			/* Get results */
			$it = \IPS\Db::i()->select( '*', 'bookmark_items', $where, $sortBy, array( ( $this->limit * ( $this->page - 1 ) ), $this->limit ) );

			$rows = iterator_to_array( $it );
			static::$rows = [];

			foreach( $rows as $index => $row )
			{
				try
				{
					$bookmark   = \IPS\bookmark\Bookmark::constructFromData( $row );
					if ( $bookmark->item AND $bookmark->item->canView() )
					{
						static::$rows[ $index ]	= $bookmark;
					}
				}
				catch ( \LogicException $e ) { }
			}
		}

		/* Return */
		return static::$rows;
	}

	/**
	 * Return the table headers
	 *
	 * @param	array|NULL	$advancedSearchValues	Advanced search values
	 * @return	array
	 */
	public function getHeaders( $advancedSearchValues )
	{
		return array();
	}
}